==> wevue-2.1.7.tgz: package/vue2/@wevue-tools/src/tools.js <==
/**
 * @lzq
 * privatefunctions
 * 
 */


/**
 * @lzq
 * app.json  {}
 */
function globalConfig() {
    try {
        return require('vueroot/app.json') || {}
    } catch (e) {
        return {}
    }
}

/**
 * @lzq
 * app.json  ->  pages:[]
 */
function getPageList() {
    let ret = []
    ret = globalConfig().pages || []
    return ret
}




/**
 * 
 * @lzq exports
 */

/**
 * @lzq
 * app.json  ->  advance:{}
 */
export function advanceAppConfig() {
    let ret = {}
    ret = globalConfig().advance || {}
    return ret
}

/**
 * @lzq
 * routers
 */

import {beforeRouteChange} from './lifecycle'
export function getAppRouters() {
    let ret = []

    const appPages = getPageList() || []
    let pageRouterItem;
    let pagePath = ''

    for (let i = 0; i < appPages.length; i++) {
        pagePath = appPages[i].replace('pages/', '')

        let tmpI = require("promise-loader?bluebird!vueroot/pages/"+pagePath+".vue")
        pageRouterItem = {
            path: `/${pagePath}`,
            component: tmpI,
            beforeEnter: (to, from, next) => {
                __WEVUE_GI.PAGEPATH = from.path
                console.log("beforeRouteChange",from.path,'->',to.path)
                let ret = beforeRouteChange(to,from)
                if(ret==true){
                    __WEVUE_GI.PAGEPATH = to.path
                }else if(ret==false){
                    __WEVUE_GI.PAGEPATH = from.path
                }else if('string' ==typeof ret){
                    __WEVUE_GI.PAGEPATH = ret
                }else{
                    __WEVUE_GI.PAGEPATH = '/'
                }

                

                next(ret)
            }
        }
        /**
         * @lzq
         * 默认打开第一个页面
         */
        if (i === 0) {
            ret.push({
                path: '/',
                redirect: `/${pagePath}`
            })
        }
        ret.push(pageRouterItem)
    }
    return ret
}

export function _clone(target){
    return JSON.parse(JSON.stringify(target))
}

==> wevue-2.3.4.tgz: package/vue2/@wevue-tools/src/tools.js <==
/**
 * @lzq
 * privatefunctions
 * 
 */


/**
 * @lzq
 * app.json  {}
 */
function globalConfig() {
    try {
        let globalAppJson = require('vueroot/app.json') || {}
        return globalAppJson.default?globalAppJson.default:globalAppJson
    } catch (e) {
        return {}
    }
}

/**
 * @lzq
 * app.json  ->  pages:[]
 */
function getPageList() {
    let ret = []
    ret = globalConfig().pages || []
    return ret
}




/**
 * 
 * @lzq exports
 */

/**
 * @lzq
 * app.json  ->  advance:{}
 */
export function advanceAppConfig() {
    let ret = {}
    ret = globalConfig().advance || {}
    return ret
}

/**
 * @lzq
 * routers
 */

import {beforeRouteChange} from './lifecycle'
export function getAppRouters() {
    let ret = []

    const appPages = getPageList() || []
    let pageRouterItem;
    let pagePath = ''

    for (let i = 0; i < appPages.length; i++) {
        pagePath = appPages[i].replace('pages/', '')

        let tmpI = require("promise-loader?bluebird!vueroot/pages/"+pagePath+".vue")
        pageRouterItem = {
            path: `/${pagePath}`,
            component: tmpI,
            beforeEnter: (to, from, next) => {
                __WEVUE_GI.PAGEPATH = from.path
                let ret = beforeRouteChange(to,from)
                if(ret==true){
                    __WEVUE_GI.PAGEPATH = to.path
                }else if(ret==false){
                    __WEVUE_GI.PAGEPATH = from.path
                }else if('string' ==typeof ret){
                    __WEVUE_GI.PAGEPATH = ret
                }else{
                    __WEVUE_GI.PAGEPATH = '/'
                }

                

                next(ret)
            }
        }
        /**
         * @lzq
         * 默认打开第一个页面
         */
        if (i === 0) {
            ret.push({
                path: '/',
                redirect: `/${pagePath}`
            })
        }
        ret.push(pageRouterItem)
    }
    return ret
}

export function _clone(target){
    return JSON.parse(JSON.stringify(target))
}
